==> tencentcloud-sdk-java-3.1.57-sources.jar: com/tencentcloudapi/nlp/v20190408/models/TextSimilarityResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.nlp.v20190408.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class TextSimilarityResponse extends AbstractModel{

    /**
    * 每个目标句子与源句子的相似度分值，按照分值降序排列
    */
    @SerializedName("Similarity")
    @Expose
    private Similarity [] Similarity;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 每个目标句子与源句子的相似度分值，按照分值降序排列 
     * @return Similarity 每个目标句子与源句子的相似度分值，按照分值降序排列
     */
    public Similarity [] getSimilarity() {
        return this.Similarity;
    }

    /**
     * Set 每个目标句子与源句子的相似度分值，按照分值降序排列
     * @param Similarity 每个目标句子与源句子的相似度分值，按照分值降序排列
     */
    public void setSimilarity(Similarity [] Similarity) {
        this.Similarity = Similarity;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "Similarity.", this.Similarity);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}

==> tencentcloud-sdk-java-3.1.281-sources.jar: com/tencentcloudapi/nlp/v20190408/models/TextSimilarityResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.nlp.v20190408.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class TextSimilarityResponse extends AbstractModel{

    /**
    * 每个目标句子与源句子的相似度分值，按照分值降序排列
    */
    @SerializedName("Similarity")
    @Expose
    private Similarity [] Similarity;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 每个目标句子与源句子的相似度分值，按照分值降序排列 
     * @return Similarity 每个目标句子与源句子的相似度分值，按照分值降序排列
     */
    public Similarity [] getSimilarity() {
        return this.Similarity;
    }

    /**
     * Set 每个目标句子与源句子的相似度分值，按照分值降序排列
     * @param Similarity 每个目标句子与源句子的相似度分值，按照分值降序排列
     */
    public void setSimilarity(Similarity [] Similarity) {
        this.Similarity = Similarity;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public TextSimilarityResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public TextSimilarityResponse(TextSimilarityResponse source) {
        if (source.Similarity != null) {
            this.Similarity = new Similarity[source.Similarity.length];
            for (int i = 0; i < source.Similarity.length; i++) {
                this.Similarity[i] = new Similarity(source.Similarity[i]);
            }
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "Similarity.", this.Similarity);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}
